@@ -6,6 +6,9 @@ from tempfile import NamedTemporaryFile
 CSV_HEADER = ['phone_number', 'user_address', 'contract_address',
               'current_balance', 'send_amount', 'timestamp']
 
+RPC_PROVIDER = 'http://127.0.0.1:8545'
+CHAIN_SPEC = 'evm:kitabu:6060:sarafu'
+
 
 class CSV_Column(IntEnum):
     Phone = 0,
